==> prestashop_1.4.9.0.zip: prestashop/modules/ogone/fr.php <==
<?php

global $_MODULE;
$_MODULE = array();
$_MODULE['<{ogone}prestashop>hookorderconfirmation_2e2117b7c81aa9ea6931641ea2c6499f'] = 'Votre commande sur';
$_MODULE['<{ogone}prestashop>hookorderconfirmation_75fbf512d744977d62599cc3f0ae2bb4'] = 'est terminée.';
$_MODULE['<{ogone}prestashop>hookorderconfirmation_30163d8fc3068e8297e7ab5bf32aec87'] = 'Votre commande vous sera expédiée dès que possible.';
$_MODULE['<{ogone}prestashop>hookorderconfirmation_0db71da7150c27142eef9d22b843b4a9'] = 'Pour toute question ou pour plus d\'informations, merci de contacter notre';
$_MODULE['<{ogone}prestashop>hookorderconfirmation_64430ad2835be8ad60c59e7d44e4b0b1'] = 'service client';
$_MODULE['<{ogone}prestashop>hookorderconfirmation_8de637e24570c1edb0357826a2ad5aea'] = 'Nous avons constaté un problème avec votre commande. Si vous pensez que c\'est une erreur, merci de contacter notre';
$_MODULE['<{ogone}prestashop>ogone_20015706a8cbd457cbb6ea3e7d5dc9b3'] = 'Configuration enregistrée';
$_MODULE['<{ogone}prestashop>ogone_6a26f548831e6a8c26bfbbd9f6ec61e0'] = 'Aide';
$_MODULE['<{ogone}prestashop>ogone_879dd0a17cb07d91581b85fa6ade410b'] = 'Ogone Payment Services est le service de paiement leader en Europe, avec une couverture mondiale.';
$_MODULE['<{ogone}prestashop>ogone_1e7bcd8050c5264ba8ea688bdb1d999b'] = 'Ogone est l’un des acteurs majeurs du paiement en ligne en Europe avec plus de %1$s35 000 clients%2$s, répartis dans %1$s45 pays%2$s.';
$_MODULE['<{ogone}prestashop>ogone_96c968b4187bdfd7fdf213816aa20998'] = 'Grâce à ses partenariats avec plus de %1$s200 banques et acquéreurs répartis%2$s sur les cinq continents, Ogone propose aux e-commerçants une plateforme capable de consolider la gestion plus de %1$s80 moyens de paiement internationaux et locaux%2$s.';
$_MODULE['<{ogone}prestashop>ogone_3936e6f93396b090fa269b25ebcffeac'] = 'Pour activer votre compte, il vous suffit de disposer d’un contrat de VAD (Vente à Distance) auprès d’une banque.';
$_MODULE['<{ogone}prestashop>ogone_b68664b2bd671c41f46e2ea168895e8a'] = 'Créez votre compte Test GRATUIT en cliquant sur le lien ci-dessous :';
$_MODULE['<{ogone}prestashop>ogone_199ab4d0550e412b6dc34cb277a8f4de'] = 'Créer votre compte de test gratuit';
$_MODULE['<{ogone}prestashop>ogone_a276e4a057c509f54db29bcaabb089ad'] = 'Ce compte de Test va vous permettre de créer votre %1$sPSPID (identifiant Ogone)%2$s, de renseigner vos informations administratives, les moyens de paiement souhaités et de paramétrer %1$sles signatures SHA-in et SHA-out%2$s qui vous sont demandées pour la configuration de votre compte PrestaShop ci-dessous.';
$_MODULE['<{ogone}prestashop>ogone_5849c2f3cca6a24cb438d8c6614729e0'] = 'Vous pourrez également effectuer des tests de paiement.';
$_MODULE['<{ogone}prestashop>ogone_ff1a5bf357135289df7454e19e068b30'] = 'Transférez votre compte de Test avec Ogone en Production';
$_MODULE['<{ogone}prestashop>ogone_263354849869cfad12ab9d6a53c4f629'] = 'Cette seconde partie va vous permettre de compléter vos données de facturation, de renseigner le numéro VAD que votre acquéreur vous aura communiqué et d’obtenir votre contrat Ogone.';
$_MODULE['<{ogone}prestashop>ogone_e6cca2e851d66adf3d816520a03f627e'] = 'Activez votre compte sur Prestashop !';
$_MODULE['<{ogone}prestashop>ogone_35af8c5fb7c6f44b6d486698fa913a9e'] = 'Il vous suffit à présent de renseigner, ci-dessous, votre PSPID ainsi que les signatures SHA-in et SHA-out paramétrées au préalable sur votre compte Ogone.';
$_MODULE['<{ogone}prestashop>ogone_959006fc1235837e923346d14b6e97f0'] = 'Pour toute question commerciale, technique ou administrative, contactez gratuitement notre service client au 01.70.70.09.03';
$_MODULE['<{ogone}prestashop>ogone_f4f70727dc34561dfde1a3c529b6205c'] = 'Configuration';
$_MODULE['<{ogone}prestashop>ogone_05d749acfbb6a79553aef6a644db881f'] = 'PSPID';
$_MODULE['<{ogone}prestashop>ogone_ac3b5413fdb77e3726a94891c9844b44'] = 'Signature SHA-in';
$_MODULE['<{ogone}prestashop>ogone_7c287610a5cd0fddf4261f153996da5e'] = 'Signature SHA-out';
$_MODULE['<{ogone}prestashop>ogone_650be61892bf690026089544abbd9d26'] = 'Mode';
$_MODULE['<{ogone}prestashop>ogone_0cbc6611f5540bd0809a388dc95a615b'] = 'Test';
$_MODULE['<{ogone}prestashop>ogone_756d97bb256b8580d4d71ee0c547804e'] = 'Production';
$_MODULE['<{ogone}prestashop>ogone_b17f3f4dcf653a5776792498a9b44d6a'] = 'Mettre à jour';
$_MODULE['<{ogone}prestashop>ogone_75310bf8b7cf2ca4e09332871f98c271'] = 'Payer avec Ogone';
$_MODULE['<{ogone}prestashop>ogone_51e550f8a0e9e127a566c21e9a15538b'] = 'Logo Ogone';
$_MODULE['<{ogone}prestashop>ogone_15ee0c3bac84f0ff0a2af1e6cdc1a048'] = 'Payer rapidement et en toute sécurité à la page suivante avec IDEAL / Mastercard / Visa / Paypal / Mister Cash / Bancontact.';
$_MODULE['<{ogone}prestashop>validation_e9f77209121063c8aedd7698f20f4878'] = 'Paramètres reçus :';
$_MODULE['<{ogone}prestashop>validation_273e5454628021d87e34051074ac62d1'] = 'Paramètres manquants';
$_MODULE['<{ogone}prestashop>validation_cbb285f0e88adea7d492a5b14b9e6d1d'] = 'Erreur (authentification refusée)';
$_MODULE['<{ogone}prestashop>validation_ee5698e64b5157ad1cbe6aa614288c33'] = 'Payment autorisé / OK';
$_MODULE['<{ogone}prestashop>validation_6b4fcb57371df22836b78f67bc444213'] = 'Statut inconnu :';
$_MODULE['<{ogone}prestashop>validation_a04830387e55082ed6096ab698ac8238'] = 'Signature SHA-1 invalide';
$_MODULE['<{ogone}prestashop>validation_7eaab6a852dfe4707acde8847dba7ce9'] = 'SHA-1 fourni';
$_MODULE['<{ogone}prestashop>validation_8fbed6331a34a844224bfee15145e00f'] = 'SHA-1 calculé';
$_MODULE['<{ogone}prestashop>validation_671c1f78cd9a17103c43a10d19157678'] = 'Clé simple :';
$_MODULE['<{ogone}prestashop>waiting_1fe3bb016fa11dd93fb1929f118fd492'] = 'Merci de patienter pendant que votre commande se valide...';

==> prestashop_1.4.10.0.zip: prestashop/modules/ogone/fr.php <==
<?php

global $_MODULE;
$_MODULE = array();
$_MODULE['<{ogone}prestashop>hookorderconfirmation_2e2117b7c81aa9ea6931641ea2c6499f'] = 'Votre commande sur';
$_MODULE['<{ogone}prestashop>hookorderconfirmation_75fbf512d744977d62599cc3f0ae2bb4'] = 'est terminée.';
$_MODULE['<{ogone}prestashop>hookorderconfirmation_30163d8fc3068e8297e7ab5bf32aec87'] = 'Votre commande vous sera expédiée dès que possible.';
$_MODULE['<{ogone}prestashop>hookorderconfirmation_0db71da7150c27142eef9d22b843b4a9'] = 'Pour toute question ou pour plus d\'informations, merci de contacter notre';
$_MODULE['<{ogone}prestashop>hookorderconfirmation_64430ad2835be8ad60c59e7d44e4b0b1'] = 'service client';
$_MODULE['<{ogone}prestashop>hookorderconfirmation_8de637e24570c1edb0357826a2ad5aea'] = 'Nous avons constaté un problème avec votre commande. Si vous pensez que c\'est une erreur, merci de contacter notre';
$_MODULE['<{ogone}prestashop>ogone_40904c61c99a28a3acc110767753fade'] = 'Avec 80 méthodes de paiement et 200 banques à travers le monde, Ogone vous propose une solution clé en main pour stimuler et sécuriser vos paiements en ligne !';
$_MODULE['<{ogone}prestashop>ogone_20015706a8cbd457cbb6ea3e7d5dc9b3'] = 'Configuration enregistrée';
$_MODULE['<{ogone}prestashop>ogone_6a26f548831e6a8c26bfbbd9f6ec61e0'] = 'Aide';
$_MODULE['<{ogone}prestashop>ogone_879dd0a17cb07d91581b85fa6ade410b'] = 'Ogone Payment Services est le service de paiement leader en Europe, avec une couverture mondiale.';
$_MODULE['<{ogone}prestashop>ogone_1e7bcd8050c5264ba8ea688bdb1d999b'] = 'Ogone est l’un des acteurs majeurs du paiement en ligne en Europe avec plus de %1$s35 000 clients%2$s, répartis dans %1$s45 pays%2$s.';
$_MODULE['<{ogone}prestashop>ogone_96c968b4187bdfd7fdf213816aa20998'] = 'Grâce à ses partenariats avec plus de %1$s200 banques et acquéreurs répartis%2$s sur les cinq continents, Ogone propose aux e-commerçants une plateforme capable de consolider la gestion plus de %1$s80 moyens de paiement internationaux et locaux%2$s.';
$_MODULE['<{ogone}prestashop>ogone_3936e6f93396b090fa269b25ebcffeac'] = 'Pour activer votre compte, il vous suffit de disposer d’un contrat de VAD (Vente à Distance) auprès d’une banque.';
$_MODULE['<{ogone}prestashop>ogone_b68664b2bd671c41f46e2ea168895e8a'] = 'Créez votre compte Test GRATUIT en cliquant sur le lien ci-dessous :';
$_MODULE['<{ogone}prestashop>ogone_199ab4d0550e412b6dc34cb277a8f4de'] = 'Créer votre compte de test gratuit';
$_MODULE['<{ogone}prestashop>ogone_a276e4a057c509f54db29bcaabb089ad'] = 'Ce compte de Test va vous permettre de créer votre %1$sPSPID (identifiant Ogone)%2$s, de renseigner vos informations administratives, les moyens de paiement souhaités et de paramétrer %1$sles signatures SHA-in et SHA-out%2$s qui vous sont demandées pour la configuration de votre compte PrestaShop ci-dessous.';
$_MODULE['<{ogone}prestashop>ogone_5849c2f3cca6a24cb438d8c6614729e0'] = 'Vous pourrez également effectuer des tests de paiement.';
$_MODULE['<{ogone}prestashop>ogone_ff1a5bf357135289df7454e19e068b30'] = 'Transférez votre compte de Test avec Ogone en Production';
$_MODULE['<{ogone}prestashop>ogone_263354849869cfad12ab9d6a53c4f629'] = 'Cette seconde partie va vous permettre de compléter vos données de facturation, de renseigner le numéro VAD que votre acquéreur vous aura communiqué et d’obtenir votre contrat Ogone.';
$_MODULE['<{ogone}prestashop>ogone_e6cca2e851d66adf3d816520a03f627e'] = 'Activez votre compte sur Prestashop !';
$_MODULE['<{ogone}prestashop>ogone_35af8c5fb7c6f44b6d486698fa913a9e'] = 'Il vous suffit à présent de renseigner, ci-dessous, votre PSPID ainsi que les signatures SHA-in et SHA-out paramétrées au préalable sur votre compte Ogone.';
$_MODULE['<{ogone}prestashop>ogone_959006fc1235837e923346d14b6e97f0'] = 'Pour toute question commerciale, technique ou administrative, contactez gratuitement notre service client au 01.70.70.09.03';
$_MODULE['<{ogone}prestashop>ogone_f4f70727dc34561dfde1a3c529b6205c'] = 'Configuration';
$_MODULE['<{ogone}prestashop>ogone_05d749acfbb6a79553aef6a644db881f'] = 'PSPID';
$_MODULE['<{ogone}prestashop>ogone_ac3b5413fdb77e3726a94891c9844b44'] = 'Signature SHA-in';
$_MODULE['<{ogone}prestashop>ogone_7c287610a5cd0fddf4261f153996da5e'] = 'Signature SHA-out';
$_MODULE['<{ogone}prestashop>ogone_650be61892bf690026089544abbd9d26'] = 'Mode';
$_MODULE['<{ogone}prestashop>ogone_0cbc6611f5540bd0809a388dc95a615b'] = 'Test';
$_MODULE['<{ogone}prestashop>ogone_756d97bb256b8580d4d71ee0c547804e'] = 'Production';
$_MODULE['<{ogone}prestashop>ogone_b17f3f4dcf653a5776792498a9b44d6a'] = 'Mettre à jour';
$_MODULE['<{ogone}prestashop>ogone_48c7c41b72e1d678923ce3571aa65b2d'] = 'Étape';
$_MODULE['<{ogone}prestashop>ogone_3afbd9828e011526955ca93b48b57524'] = 'Voir capture d\'écran';
$_MODULE['<{ogone}prestashop>ogone_75310bf8b7cf2ca4e09332871f98c271'] = 'Payer avec Ogone';
$_MODULE['<{ogone}prestashop>ogone_51e550f8a0e9e127a566c21e9a15538b'] = 'Logo Ogone';
$_MODULE['<{ogone}prestashop>ogone_15ee0c3bac84f0ff0a2af1e6cdc1a048'] = 'Payer rapidement et en toute sécurité à la page suivante avec IDEAL / Mastercard / Visa / Paypal / Mister Cash / Bancontact.';
$_MODULE['<{ogone}prestashop>validation_e9f77209121063c8aedd7698f20f4878'] = 'Paramètres reçus :';
$_MODULE['<{ogone}prestashop>validation_273e5454628021d87e34051074ac62d1'] = 'Paramètres manquants';
$_MODULE['<{ogone}prestashop>validation_cbb285f0e88adea7d492a5b14b9e6d1d'] = 'Erreur (authentification refusée)';
$_MODULE['<{ogone}prestashop>validation_ee5698e64b5157ad1cbe6aa614288c33'] = 'Payment autorisé / OK';
$_MODULE['<{ogone}prestashop>validation_6b4fcb57371df22836b78f67bc444213'] = 'Statut inconnu :';
$_MODULE['<{ogone}prestashop>validation_a04830387e55082ed6096ab698ac8238'] = 'Signature SHA-1 invalide';
$_MODULE['<{ogone}prestashop>validation_7eaab6a852dfe4707acde8847dba7ce9'] = 'SHA-1 fourni';
$_MODULE['<{ogone}prestashop>validation_8fbed6331a34a844224bfee15145e00f'] = 'SHA-1 calculé';
$_MODULE['<{ogone}prestashop>validation_671c1f78cd9a17103c43a10d19157678'] = 'Clé simple :';
$_MODULE['<{ogone}prestashop>waiting_1fe3bb016fa11dd93fb1929f118fd492'] = 'Merci de patienter pendant que votre commande se valide...';
